@@ -23,6 +23,7 @@ from .exceptions import (
     AccessDeniedException,
     DocumentAlreadyExists,
     DocumentPermissionLimit,
+    DoesNotExistException,
     DuplicateDocumentContent,
     DuplicateDocumentVersionName,
     InvalidDocument,
@@ -1656,7 +1657,6 @@ class SimpleSystemManagerBackend(BaseBackend):
         filter_keys = []
         for filter_obj in parameter_filters or []:
             key = filter_obj["Key"]
-            values = filter_obj.get("Values")
 
             if key == "Path":
                 option = filter_obj.get("Option", "OneLevel")
@@ -1673,7 +1673,9 @@ class SimpleSystemManagerBackend(BaseBackend):
                     f"The following filter key is not valid: {key}. Valid filter keys include: [Type, KeyId]."
                 )
 
-            if key in ["Name", "Type", "Path", "Tier", "Keyid"] and not values:
+            if key in ["Name", "Type", "Path", "Tier", "Keyid"] and not filter_obj.get(
+                "Values"
+            ):
                 raise InvalidFilterValue(
                     "The following filter values are missing : null for filter key Name."
                 )
@@ -1684,16 +1686,19 @@ class SimpleSystemManagerBackend(BaseBackend):
                 )
 
             if key == "Path":
+                path_values = filter_obj["Values"]
                 if option not in ["Recursive", "OneLevel"]:
                     raise InvalidFilterOption(
                         f"The following filter option is not valid: {option}. Valid options include: [Recursive, OneLevel]."
                     )
-                if any(value.lower().startswith(("/aws", "/ssm")) for value in values):
+                if any(
+                    value.lower().startswith(("/aws", "/ssm")) for value in path_values
+                ):
                     raise ValidationException(
                         'Filters for common parameters can\'t be prefixed with "aws" or "ssm" (case-insensitive). '
                         "When using global parameters, please specify within a global namespace."
                     )
-                for value in values:
+                for value in path_values:
                     if value.lower().startswith(("/aws", "/ssm")):
                         raise ValidationException(
                             'Filters for common parameters can\'t be prefixed with "aws" or "ssm" (case-insensitive). '
@@ -1713,14 +1718,16 @@ class SimpleSystemManagerBackend(BaseBackend):
                         )
 
             if key == "Tier":
-                for value in values:
+                tier_values = filter_obj["Values"]
+                for value in tier_values:
                     if value not in ["Standard", "Advanced", "Intelligent-Tiering"]:
                         raise InvalidFilterOption(
                             f"The following filter value is not valid: {value}. Valid values include: [Standard, Advanced, Intelligent-Tiering]."
                         )
 
             if key == "Type":
-                for value in values:
+                type_values = filter_obj["Values"]
+                for value in type_values:
                     if value not in ["String", "StringList", "SecureString"]:
                         raise InvalidFilterOption(
                             f"The following filter value is not valid: {value}. Valid values include: [String, StringList, SecureString]."
@@ -2315,9 +2322,10 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def get_maintenance_window(self, window_id: str) -> FakeMaintenanceWindow:
         """
-        The window is assumed to exist - no error handling has been implemented yet.
         The NextExecutionTime-field is not returned.
         """
+        if window_id not in self.windows:
+            raise DoesNotExistException(window_id)
         return self.windows[window_id]
 
     def describe_maintenance_windows(
@@ -2337,8 +2345,10 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def delete_maintenance_window(self, window_id: str) -> None:
         """
-        Assumes the provided WindowId exists. No error handling has been implemented yet.
+        Delete a maintenance window.
         """
+        if window_id not in self.windows:
+            raise DoesNotExistException(window_id)
         del self.windows[window_id]
 
     def create_patch_baseline(
